# nf-core/fastqrepair: Output

## Introduction

This document describes the output produced by the pipeline.

## Pipeline overview

The nf-core/fastqrepair pipeline is built using [Nextflow](https://www.nextflow.io/). Output files are gathered into the `repaired` subfolder of the output folder set up using the `--outdir` command line parameter.

```
<output folder>
  - pipeline_info/
  - QC/
    - fastqc/
    - multiqc/
  - repaired/
```

<details markdown="1">
<summary>Folders content</summary>

- `pipeline_info` contains report metrics generated during the [workflow execution](#pipeline-information)
- `QC` contains [FastQC](#fastqc) QC analysis results and [MultiQC](#multiqc) reports
- `repaired` contains repaired fastq files and relative quality reports
  - `mysampleA_R1.fastq.gz` (and `mysampleA_R2.fastq.gz`) are the repaired fastq files
  - `mysampleA_R1.report` (and `mysampleA_R2.report`) are the summaries of the cleaning task

</details>

### FastQC

[FastQC](http://www.bioinformatics.babraham.ac.uk/projects/fastqc/) gives general quality metrics about your sequenced reads. It provides information about the quality score distribution across your reads, per base sequence content (%A/T/G/C), adapter contamination and overrepresented sequences. For further reading and documentation see the [FastQC help pages](http://www.bioinformatics.babraham.ac.uk/projects/fastqc/Help/).

<details markdown="1">
<summary>Output files</summary>

- `fastqc/`
  - `*_fastqc.html`: FastQC report containing quality metrics.
  - `*_fastqc.zip`: Zip archive containing the FastQC report, tab-delimited data file and plot images.

</details>

### MultiQC

[MultiQC](http://multiqc.info) is a visualization tool that generates a single HTML report summarising all samples in your project. Most of the pipeline QC results are visualised in the report and further statistics are available in the report data directory.

<details markdown="1">
<summary>Output files</summary>

- `multiqc/`
  - `multiqc_report.html`: a standalone HTML file that can be viewed in your web browser.
  - `multiqc_data/`: directory containing parsed statistics from the different tools used in the pipeline.
  - `multiqc_plots/`: directory containing static images from the report in various formats.

</details>

Results generated by MultiQC collate pipeline QC from supported tools e.g. FastQC. The pipeline has special steps which also allow the software versions to be reported in the MultiQC output for future traceability. For more information about how to use MultiQC reports, see <http://multiqc.info>.

### Pipeline information

<details markdown="1">
<summary>Output files</summary>

- `pipeline_info/`
  - Reports generated by Nextflow: `execution_report.html`, `execution_timeline.html`, `execution_trace.txt` and `pipeline_dag.html`.
  - Reports generated by the pipeline: `pipeline_report.html`, `pipeline_report.txt` and `software_versions.yml`. The `pipeline_report*` files will only be present if the `--email` / `--email_on_fail` parameter's are used when running the pipeline.
  - Reformatted samplesheet files used as input to the pipeline: `samplesheet.valid.csv`.
  - Parameters used by the pipeline run: `params.json`.

</details>
